<?php
if ( ! defined( 'ABSPATH' ) ) { 
	exit; // Exit if accessed directly
}
/*
 * Plugin Name: Analytify for WooCommerce
 * Plugin URI: https://wp-analytify.com/enhanced-ecommerce-google-analytics-for-woocommerce/
 * Description: This Add-on will track the e-commerce behaviour of users, digital Sales, Transactions and Revenues in Google Analytics and Displays Stats in a unique and intiutive way which is very understandable even for non-technical WordPress users.
 * Version: 1.0.2
 * Author: WooThemes
 * Author URI: http://woothemes.com/
 * Developer: Analytify LLC
 * Developer URI: http://wp-analytify.com/
 * License: GPLv2+
 * Min WP Version: 3.0
 * Max WP Version: 4.4.1
 * Text Domain: wp-analytify-woocommerce
 * Domain Path: /languages/
 * WC requires at least: 2.3
 * WC tested up to: 2.3.8
 */

/**
 * Check if WooCommerce is active or not
 **/
if ( !in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	add_action( 'admin_notices', 'wpa_check_woo_admin_notice' );
	return;
}

/**
 * Check if Analytify is active
 **/
if ( !in_array( 'wp-analytify-pro/wp-analytify-pro.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	add_action( 'admin_notices', 'wpa_check_analytify_admin_notice' );
	return;
}

function wpa_check_woo_admin_notice() {
	$class = "error";
	$message = esc_html__( 'This plugin works with WooCommerce plugin, Please activate WooCommerce first.', 'wp-analytify-woocommerce' );
		echo"<div class=\"$class\"> <p>$message</p></div>"; 
}

function wpa_check_analytify_admin_notice() {
	$class = "error";
	$message = esc_html__( 'This plugin works with Analytify plugin, Please activate Analytify PRO first.', 'wp-analytify-woocommerce' );
		echo"<div class=\"$class\"> <p>$message</p></div>";
}



class WP_Analytify_WooCommerce {

	/**
	 * @var         WP_Analytify_WooCommerce $instance The one true WP_Analytify_WooCommerce
	 * @since       1.0.0
	 */
	private static $instance;

	public $catpage_json			=	array();
	public $catpage_json_ATC_link	=	array();

	/**
	 * Get active instance
	 *
	 * @access      public
	 * @since       1.0.0
	 * @return      object self::$instance The one true WP_Analytify_WooCommerce
	 */
	public static function instance() {
		
		if( !self::$instance ) {
			self::$instance = new WP_Analytify_WooCommerce();
			self::$instance->setup_constants();
			self::$instance->includes();
			self::$instance->load_textdomain();
			self::$instance->hooks();
		}
		return self::$instance;
	}

	/**
	 * Setup plugin constants
	 *
	 * @access      private
	 * @since       1.0.0
	 * @return      void
	 */
	private function setup_constants() {

		// Setting Global Values
		$this->define( 'WC_ANALYTIFY_PLUGIN_FILE', __FILE__ );
		$this->define( 'WC_ANALYTIFY_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
		$this->define( 'WC_ANALYTIFY_PLUGIN_DIR', dirname( __FILE__ ) );
		$this->define( 'WC_ANALYTIFY_PRODUCT_NAME', "Enhanced Ecommerce Google Analytics for WooCommerce Addon" );
		$this->define( 'WC_ANALYTIFY_STORE_URL', "https://wp-analytify.com" );

	}

	/**
	 * Define constant if not already set
	 * @param  string $name
	 * @param  string|bool $value
	 */
	private function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Include necessary files
	 *
	 * @access      private
	 * @since       1.0.0
	 * @return      void
	 */
	private function includes() {


	}

	/**
	 * Run action and filter hooks
	 *
	 * @access      private
	 * @since       1.0.0
	 * @return      void
	 *
	 */
	private function hooks() {

		// add menu for WooCommerce Analytics Dashboard
		add_action( 'admin_menu', array( $this, 'add_menu_woo' ), 11);

		add_action( 'admin_init', 				array( $this, 'wpa_woo_update'), 0);
		add_action( 'woocommerce_license_key', 	array( $this, 'wpa_woo_license_key' ));
		add_action( 'admin_init', 				array( $this, 'wp_analytify_woo_register_option' ));
		add_action( 'admin_init', 				array( $this, 'analytify_activate_license' ));
		add_action( 'admin_init', 				array( $this, 'analytify_deactivate_license' ));

		add_action('admin_notices', 			array( $this, 'wp_analytify_woo_admin_notice') );

		add_action( 'ga_ecommerce_js', 			array( $this, 'add_ga_ecommerce_js'), 1);
		add_action( 'woocommerce_after_add_to_cart_button', array( $this, 'add_to_cart') );
		add_action( 'woocommerce_after_cart', 	array( $this, 'remove_from_cart' ));
		add_action( 'woocommerce_after_single_product', array( $this, 'view_product_detail') );
		add_action( 'woocommerce_after_shop_loop_item', array( $this, 'bind_product_metadata') );
		add_action( 'wp_footer', 				array( $this, 'product_impressions') );
		
		add_action( 'woocommerce_after_cart_totals', array( $this, 'product_review_cart_step1' ) );
		add_action( 'woocommerce_after_checkout_billing_form', array( $this, 'product_checkout_step2' ) );
		add_action( 'woocommerce_after_checkout_shipping_form', array( $this, 'product_checkout_step3' ) );
        add_action( 'woocommerce_after_checkout_form', array( $this, 'product_checkout_step4' ) );

        add_action( 'woocommerce_thankyou', 	array( $this, 'product_purchases') );
	}

	/**
	 * Internationalization
	 *
	 * @access      public
	 * @since       1.0.0
	 * @return      void
	 */
	public function load_textdomain() {

		$plugin_dir = dirname( WC_ANALYTIFY_PLUGIN_BASENAME );
		load_plugin_textdomain( 'wp-analytify-woocommerce', false , $plugin_dir . '/languages/');
	}

	/**
	 * Add menu for WooCommerce dashboard page
	 *
	 * @access public
	 * @return void
	 */
	public static function add_menu_woo() {

		add_submenu_page( 'analytify-dashboard', esc_html__( 'Track everything in WooCommerce with Analytify.', 'wp-analytify-woocommerce' ), ' <b style="color:#5fcf80">' . esc_html__( 'WooCommerce', 'wp-analytify-woocommerce' ) . '</b>', 'edit_posts', 'analytify-woocommerce', array(
			__CLASS__,
			'analytify_page_file_path'
		));
	}

	/**
	 * WooCommerce Addon Update plugins
	 *
	 * @access public
	 * @return void
	 */

	function wpa_woo_update() {

		// retrieve our license key from the DB
		$wpa_license_key = trim( get_option( 'analytify_woo_license_key' ) );

		// setup the updater
		$edd_updater = new EDD_SL_Plugin_Updater( WC_ANALYTIFY_STORE_URL, __FILE__, array( 
					'version'   => '1.0.2',               // current version number
					'license'   => $wpa_license_key,        // license key (used get_option above to retrieve from DB)
					'item_name' => WC_ANALYTIFY_PRODUCT_NAME,    // name of this plugin
					'author'    => 'Muhammad Adnan'  // author of this plugin
				)
		);
	}

	/*
	 * Output Analytify for WooCommerce license activation key fields/inputs
	 * @access public 
	 *
	 */
	function wpa_woo_license_key() {

		$license_woo  = get_option( 'analytify_woo_license_key' );
		$status_woo   = get_option( 'analytify_woo_license_status' );

		?>
		<tr><th></th><td><hr /></td></tr>
		<tr valign="top"> 
				<th scope="row" valign="top">
					<?php esc_html_e( 'Analytify for WooCommerce (License Key):', 'wp-analytify-woocommerce' ); ?>
				</th>
				<td>
					<input id="analytify_woo_license_key" name="analytify_woo_license_key" type="text" class="regular-text" value="<?php esc_attr_e( $license_woo ); ?>" />
				</td>
		</tr>

		<?php

		if( !empty( $license_woo ) ) { ?>

			<tr valign="top"> 
							<th scope="row" valign="top">

							</th>
							<td>
								<?php if( $status_woo !== false && $status_woo == 'valid' ) { ?>
									<span style="color:green;"><?php _e('Active'); ?></span>
									<?php wp_nonce_field( 'analytify_nonce', 'analytify_nonce' ); ?>
									<input type="submit" class="button-secondary" name="analytify_woo_license_deactivate" value="<?php esc_html_e( 'Deactivate License', 'wp-analytify-woocommerce' ); ?>"/>
								<?php } else {
									wp_nonce_field( 'analytify_nonce', 'analytify_nonce' ); ?>
									<span style="color:red;"><?php _e( $status_woo ); ?></span>
									<input type="submit" class="button-secondary" name="analytify_woo_license_activate" value="<?php esc_html_e( 'Activate License', 'wp-analytify-woocommerce' ); ?>"/>
								<?php } ?>
							</td>
			</tr>

		<?php 
		}
		?>
		<?php

	}

	function wp_analytify_woo_register_option() {
			// creates our settings in the options table
			register_setting('analytify-settings', 'analytify_woo_license_key', array( $this, 'analytify_woo_sanitize_license' ));
	}


	function analytify_woo_sanitize_license( $new ) {

		$old = get_option( 'analytify_woo_license_key' );
  
		if( $old && $old != $new ) {

			delete_option( 'analytify_woo_license_status' ); // new license has been entered, so must reactivate
		  
		}
		  return $new;
	}

	/************************************
		* Activate a license key
		*************************************/

		function analytify_activate_license() {

		  // listen for our activate button to be clicked
		  if( isset( $_POST['analytify_woo_license_activate'] ) ) {
			
			// run a quick security check 
			if( ! check_admin_referer( 'analytify_nonce', 'analytify_nonce' ) )   
			  
			  return; // get out if we didn't click the Activate button

			// retrieve the license from the database
			$license = trim( get_option( 'analytify_woo_license_key' ) );
			  

			// data to send in our API request
			$api_params = array( 
			  'edd_action'=> 'activate_license',
			  'license'   => $license, 
			  'item_name' => urlencode( WC_ANALYTIFY_PRODUCT_NAME ), // the name of our product in EDD
			  'url'       => home_url()
			);
			
			// Call the custom API.
			$response = wp_remote_get( esc_url_raw(add_query_arg( $api_params, WC_ANALYTIFY_STORE_URL )), array( 'timeout' => 15, 'sslverify' => false ) );
			//print_r($response); 
			// make sure the response came back okay
			if ( is_wp_error( $response ) )
			  
			  return false;

			// decode the license data
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			// $license_data->license will be either "valid" or "invalid"
			update_option( 'analytify_woo_license_status', $license_data->license );

		  }
		}

		/***********************************************
		* Illustrates how to deactivate a license key.
		* This will descrease the site count
		***********************************************/

		function analytify_deactivate_license() {

		  // listen for our activate button to be clicked
		  if( isset( $_POST['analytify_woo_license_deactivate'] ) ) {

			// run a quick security check 
			if( ! check_admin_referer( 'analytify_nonce', 'analytify_nonce' ) )   
			  return; // get out if we didn't click the Activate button

			// retrieve the license from the database
			$license = trim( get_option( 'analytify_woo_license_key' ) );
			  

			// data to send in our API request
			$api_params = array( 
			  'edd_action'=> 'deactivate_license', 
			  'license'   => $license, 
			  'item_name' => urlencode( WC_ANALYTIFY_PRODUCT_NAME ), // the name of our product in EDD
			  'url'       => home_url()
			);
			
			// Call the custom API.
			$response = wp_remote_get( esc_url_raw(add_query_arg( $api_params, WC_ANALYTIFY_STORE_URL )), array( 'timeout' => 15, 'sslverify' => false ) );

			// make sure the response came back okay
			if ( is_wp_error( $response ) )
				return false;

			// decode the license data
			$license_data = json_decode( wp_remote_retrieve_body( $response ) );

			// $license_data->license will be either "deactivated" or "failed"
			if( $license_data->license == 'deactivated' ){
			  
			  delete_option( 'analytify_woo_license_key' );
			  unset($license);
			  delete_option( 'analytify_woo_license_status' );
			
			}
		  }
		}



	/**
	 * Include file for WooCommerce dashboard page
	 *
	 * @access public
	 * @return void
	 */
	public static function analytify_page_file_path () {
		
		$screen = get_current_screen();

		if( strpos( $screen->base, 'analytify-woocommerce' ) !== false ) {
			include( WC_ANALYTIFY_PLUGIN_DIR . '/includes/woocommerce-dashboard.php' );
		}
	}

	// Initialize e-commerce JS
	public static function add_ga_ecommerce_js() {

		echo "ga('require', 'ec');";
		echo "ga('require', 'displayfeatures');";
		echo "var ga_currency = '" . get_woocommerce_currency() . "';";
		echo 'ga("set", "&cu", ga_currency);';
	}


	/**
	 * Add Inline JS depending on WooCommerce version
	 *
	 * @access public
	 * @return void
	 */
	function add_inline_js_wpa_woo($code) {

		global $woocommerce;

		if (version_compare($woocommerce->version, "2.1", ">=")) {
				wc_enqueue_js($code);
		} else {
				$woocommerce->add_inline_js($code);
		}
	}


	/**
	 * Enhanced E-commerce tracking for single product add to cart
	 *
	 * @access public
	 * @return void
	 */
	function add_to_cart() {

		/*
		 * return if not product page       
		 */

		if ( ! is_single() )
			return;

		$code = '
				
				jQuery("button[class*=single_add_to_cart_button]").click(function(e) {

							// Enhanced E-commerce Add to cart clicks 
							ga("ec:addProduct", {
									"id" : wpa_woo.p_ID,
									"name": wpa_woo.p_name,
									"category" :wpa_woo.p_category,
									"price": wpa_woo.p_price,
									"quantity" :jQuery(this).parent().find("input[name=quantity]").val()
								});
							ga("ec:setAction", "add");
							ga("send", "event", "Enhanced-Ecommerce","click", "add_to_cart_click");
							//e.preventDefault();
				});
			';

		$this->add_inline_js_wpa_woo($code);
	}


	/**
	 * Enhanced E-commerce tracking for single product remove from cart
	 *
	 * @access public
	 * @return void
	 */
	function remove_from_cart() {

		global $woocommerce;
		
		$cart_products = array();
		$categories = '';
		$code = '';

		foreach ( $woocommerce->cart->cart_contents as $key => $value ) {

			$p = get_product( $value["product_id"] );

			/*echo '<pre>';
			print_r($p);
			echo '</pre>';*/

			$remove_url = html_entity_decode( $woocommerce->cart->get_remove_url( $key ) );

			$category = get_the_terms( $value["product_id"], "product_cat" );
				
			if ($category) {
				foreach ($category as $term) {
					$categories .= $term->name . ",";
				}
			}

			$categories = rtrim( $categories, "," );

			$cart_products[$remove_url]	=	array(
					"p_ID" 			=>	esc_html( $p->id ),
					"p_sku"			=>	esc_html( $p->get_sku() ? $p->get_sku() : $p->id ),
					"p_name"		=>	esc_html( $p->get_title() ),
					"p_price"		=>	esc_html( $p->get_price() ),
					"p_category"	=>	esc_html( $categories ),
					"p_quantity"	=>	$woocommerce->cart->cart_contents[$key]["quantity"]
			);
		}

		$this->add_inline_js_wpa_woo( "cart_products=" . json_encode( $cart_products ) . ";" );

		$code .= "
		
				$('a[href*=\"?remove_item\"]').click(function(e){

					item = jQuery(this).attr('href');

					ga('ec:addProduct', {
							'id':cart_products[item].p_ID,
							'name': cart_products[item].p_name,
							'category': cart_products[item].p_category,
							'price': cart_products[item].p_price,
							'quantity': cart_products[item].p_quantity
					});         
					ga('ec:setAction', 'remove');
					ga('send', 'event', 'Enhanced-Ecommerce', 'click', 'removeFromCartClick');

				});
				
				";


		$this->add_inline_js_wpa_woo( $code );

		
	}


	/*
	 * Track product detail events
	 *
	 * @access public
	 * @return void 
	 */

	function view_product_detail() {

		global $product;

		$categories = "";

		if( is_product() ) {

			$category = get_the_terms( $product->ID, "product_cat" );

			if ($category) {
				foreach ($category as $term) {
					$categories .= $term->name . ",";
				}
			}

			$categories = rtrim( $categories, "," );

			//product detail view json
			$p_detail_view_json = array(
										"p_ID" 			=> esc_html( $product->id ),
										"p_sku" 		=> $product->get_sku() ? $product->get_sku() : $product->id,                   
										"p_name" 		=> $product->get_title(),
										"p_category" 	=> $categories,
										"p_price" 		=> $product->get_price()
								);

			if ( empty( $p_detail_view_json ) ) {
				$p_detail_view_json = array();
			}

			//product detail view json
			$this->add_inline_js_wpa_woo( "wpa_woo=" . json_encode( $p_detail_view_json ) . ";" );

			$code = '
					ga("ec:addProduct", {
						"id": wpa_woo.p_ID,
						"name": wpa_woo.p_name,
						"category": wpa_woo.p_category,
					});
					ga("ec:setAction", "detail");
					ga("send", "event", "Tracking by Analytify", "detail","product detail view"); 
				';

			$this->add_inline_js_wpa_woo( $code );
		}
	}


	/*
	 * Bind product data
	 *
	 * @access public
	 * @return void 
	 */

	function bind_product_metadata() {

		global $product;
		global $catpage_json, $catpage_json_ATC_link;

		$category = get_the_terms( $product->ID, "product_cat" );
		$categories = "";

		if ( $category ) {

			foreach ( $category as $term ) {
				$categories .= $term->name . ",";
			}
		}

		// Remove last comma(,) if there are multiple categories.
		$categories = rtrim( $categories, "," );

		if ( is_product_category() || is_search() || is_shop() ) {

			/*            	
				if (!is_array($catpage_json) && !is_array($catpage_json_ATC_link)){
						$catpage_json=array();
						$catpage_json_ATC_link=array();
				}
			*/

			//cat page link array
			$catpage_json_ATC_link[$product->add_to_cart_url()] = array( "link" => get_permalink( $product->id ) );

			$catpage_json[get_permalink( $product->id )] =  array(
						"p_ID" 			=>	esc_html( $product->id ),
						"p_sku" 		=>	esc_html( $product->get_sku() ? $product->get_sku() : $product->id ),
						"p_name" 		=>	esc_html( $product->get_title() ),
						"p_price" 		=>	esc_html( $product->get_price() ),
						"p_category" 	=>	esc_html( $categories ),
						"p_position" 	=>	++$_SESSION['t_npcnt'], 
				);

		}
	}

	/**
	 * Enhanced E-commerce tracking for product impressions
	 *
	 * @access public
	 * @return void
	 */
	
	function product_impressions() {

		global $catpage_json, $catpage_json_ATC_link;
		$code =	'';

		$this->add_inline_js_wpa_woo( "cat_page_link=" . json_encode( $catpage_json_ATC_link ) . ";" );
		$this->add_inline_js_wpa_woo( "cat_page=" . json_encode( $catpage_json ) . ";" );

		$this->js_calls();

		// Track impressions for only Shop Page.
		if( is_shop() and ! is_search() ) {

			$code .= '
					if( cat_page.length !== 0 ){
						product_impressions( cat_page, "Shop Page", "shopPage" );	
					}

					// Track Clicks on Products
					jQuery("a:not(.product_type_variable, .product_type_grouped)").on( "click", function() {
						url = jQuery(this).attr("href");
						product_clicks( url, cat_page, "Shop Page", "shopPage" );
					});';

		}

		if( is_product_category() ) {

			$code .= '
					if( cat_page.length !== 0 ){
						product_impressions( cat_page, "Category Page", "categoryPage" );	
					}

					// Track Clicks on Products
					jQuery("a:not(.product_type_variable, .product_type_grouped)").on( "click", function() {
						url = jQuery(this).attr("href");
						product_clicks( url, cat_page, "Category Page", "categoryPage" );
					});';

		}

		if( is_search() ) {

			$code .= '
					if( cat_page !== null ) {

						if( cat_page.length !== 0 ) {
							product_impressions( cat_page, "Search Page", "searchPage" );	
						}

						// Track Clicks on Products
						jQuery("a:not(.product_type_variable, .product_type_grouped)").on( "click", function() {
							url = jQuery(this).attr("href");
							product_clicks( url, cat_page, "Search Page", "searchPage" );
						});
					}
				';

		}

		if( is_product_category() || is_shop() || is_search() ) {

			$code .='
					jQuery("a[href*=add-to-cart]").on( "click", function() {

						url = $(this).attr("href");
						qty = $(this).parent().find("input[name=quantity]").val();
			
							if( qty == "" || qty === undefined) {
								qty = "1";
							}
						products_addToCart( url, cat_page_link, cat_page, qty );
					});
			';
		}


		if ( is_home() || is_product() || is_product_category() || is_search() || is_shop() ) {
			$this->add_inline_js_wpa_woo( $code );
		}

	}

	function js_calls() {

		$code = '
					function product_impressions ( products_list, list_name, label ) {

						t_json_length = Object.keys(products_list).length

						for(var p_index in products_list) {

							ga("ec:addImpression", {
											"id": products_list[p_index].p_ID,
											"name": products_list[p_index].p_name,
											"category": products_list[p_index].p_category,
											"list": list_name,
											"price": products_list[p_index].p_price,
											"position": products_list[p_index].p_position
											,
										});
							}
							ga("send", "event", "Tracking by Analytify", "onLoad", "productImpression_" + label); 
					}

					// Track product clicks

					function product_clicks( url, products_list, list_name, label ) {

						if( products_list.hasOwnProperty( url ) ) {
	 
							t_call_fired = true;

							ga( "ec:addProduct", {              
											"id": products_list[url].p_ID,
											"name": products_list[url].p_name,
											"category": products_list[url].p_category,
											"price": products_list[url].p_price,
											"position": products_list[url].p_position,
								});
							ga( "ec:setAction", "click", { "list" : list_name } );
							ga( "send", "event", "Tracking by Analytify", "click", "productClick_" + label );  

						} else {
							t_call_fired = false;
						}

						return t_call_fired;
					}

					// Track product (Add to Cart) clicks

					function products_addToCart( url, url_addToCart, products_list, qty ) {

						index = url_addToCart[url]["link"];

						if ( products_list.hasOwnProperty( index ) ) {

							t_call_fired = true;

							ga("ec:addProduct", {
							   "id": products_list[index].p_ID,
							   "name": products_list[index].p_name,
							   "category": products_list[index].p_category,
							   "price": products_list[index].p_price,
								"quantity" : qty
							});

							ga("ec:setAction", "add");
							ga("send", "event", "Tracking by Analytify", "click", "addToCartClick" ); 

						} else {
							t_call_fired = false;
						}    

						return t_call_fired;

					}';

		$this->add_inline_js_wpa_woo($code);

	}
																			 
	/**
	 * Tracking product purchases/transactions
	 * Thankyou page i.e Order Confirmed  Step 5
	 *
	 * @access public
	 * @return void
	 */
	function product_purchases( $orderID ) {

			global $woocommerce;

			$coupons_list    = '';
			$code            = '';
			$orderShipping   = 0;

			if ( !$orderID )
				return;

			$order = new WC_Order( $orderID );

			// Bind JSON of product transaction details i.e products details
			if ( $order->get_items() ) {

				foreach ( $order->get_items() as $item ) {
					$_product = $order->get_product_from_item( $item );

					if ( isset( $_product->variation_data ) ) {
					  $categories = esc_js( woocommerce_get_formatted_variation( $_product->variation_data, true ) );
					} else {
						$out = array();
						$categories = get_the_terms( $_product->id, "product_cat" );
						if ( $categories ) {
							foreach ($categories as $category) {
								$out[] = $category->name;
							}
						}
						$categories = esc_js( join( ",", $out ) );
					}

					$orders_list[ get_permalink($_product->id) ] = array(
							"p_ID"			=> esc_html( $_product->id ),
							"p_sku"			=> esc_js( $_product->get_sku() ? $_product->get_sku() : $_product->id ),
							"p_name"		=> esc_js( $item["name"] ),
							"p_price"		=> esc_js( $order->get_item_total($item) ),
							"p_category"	=> $categories,
							"p_quantity"	=> esc_js( $item["qty"] )
						  );
				}
				//make json for prod meta data on order page
				$this->add_inline_js_wpa_woo( "orders_list=" . json_encode( $orders_list ) . ";" );
			}

			// Fetch currently used Coupon Codes

			if ( $order->get_used_coupons() ) {

				$coupons_count = count( $order->get_used_coupons() );
				$i = 1;

				foreach ( $order->get_used_coupons() as $coupon ) {
					$coupons_list .= $coupon;
					if ( $i < $coupons_count )
						$coupons_list .= ', ';
					$i++;
				}
			}
			
			if ( version_compare( $woocommerce->version, "2.1", ">=" ) ) {
				$orderShipping = $order->get_total_shipping();
			} else {
				$orderShipping = $order->get_shipping();
			}

			// Transaction data
			$ordersExtras = array(
								"id"            =>  esc_js( $order->get_order_number() ),
								"affiliation"   =>  esc_js( get_bloginfo('name') ),
								"revenue"       =>  esc_js( $order->get_total() ),
								"tax"           =>  esc_js( $order->get_total_tax() ),
								"shipping"      =>  esc_js( $orderShipping ),
								"coupon"        =>  $coupons_list
				);
			$this->add_inline_js_wpa_woo( "orders_extras=" . json_encode( $ordersExtras ) . ";" );

			$code .='
					for( var index in orders_list ) {

						ga("ec:addProduct", { 
							"id":       orders_list[index].p_ID,
							"name":     orders_list[index].p_name, 
							"category": orders_list[index].p_category,
							"price":    orders_list[index].p_price,
							"quantity": orders_list[index].p_quantity,
						});
					}
					
					ga( "ec:setAction", "checkout", { "step": 5 });

					ga( "ec:setAction", "purchase", {

						"id":           orders_extras.id,
						"affiliation":  orders_extras.affiliation,
						"revenue":      orders_extras.revenue,
						"tax":          orders_extras.tax,
						"shipping":     orders_extras.shipping,
						"coupon":       orders_extras.coupon

					});

					ga( "send", "event", "Tracking by Analytify", "onLoad", "orderConfirmed" );      
				 ';

			$this->add_inline_js_wpa_woo( $code );
	}

	/*
	 * Tracking Product Checkouts - Step 1 
	 * Review Cart Page
	 */
	function product_review_cart_step1() {

		global $woocommerce;
		
		$cart_products = array();
		$categories = '';
		$code = '';

		foreach ( $woocommerce->cart->cart_contents as $key => $value ) {

			$p = get_product( $value["product_id"] );

			$category = get_the_terms( $value["product_id"], "product_cat" );

			if ($category) {
				foreach ($category as $term) {
					$categories .= $term->name . ",";
				}
			}

			$categories = rtrim( $categories, "," );

			$cart_checkout_products[get_permalink($p->id)]	=	array(
					"p_ID" 			=>	esc_html( $p->id ),
					"p_sku"			=>	esc_html( $p->get_sku() ? $p->get_sku() : $p->id ),
					"p_name"		=>	esc_html( $p->get_title() ),
					"p_price"		=>	esc_html( $p->get_price() ),
					"p_category"	=>	esc_html( $categories ),
					"p_quantity"	=>	$value["quantity"]
			);
		}

		$this->add_inline_js_wpa_woo( "cart_checkout_products=" . json_encode( $cart_checkout_products ) . ";" );

		$code = '

                for(var item in cart_checkout_products) {

					ga("ec:addProduct", {
						"id": cart_checkout_products[item].p_ID,
						"name": cart_checkout_products[item].p_name,
						"category": cart_checkout_products[item].p_category,
						"price": cart_checkout_products[item].p_price,
						"quantity": cart_checkout_products[item].p_quantity
					});
				}';

        $code  = $code . 'ga("ec:setAction","checkout", { "step": 1 });';
        $code .= 'ga( "send", "event", "Tracking by Analytify","onLoad","Product Review Cart" );';

        $this->add_inline_js_wpa_woo( $code );

	}

	/*
	 * Tracking Product Checkouts - Step 2
	 * Billing form
	 */
	function product_checkout_step2() {

		global $woocommerce;
		
		$cart_products = array();
		$categories = '';
		$code = '';

		foreach ( $woocommerce->cart->cart_contents as $key => $value ) {

			$p = get_product( $value["product_id"] );

			$category = get_the_terms( $value["product_id"], "product_cat" );

			if ($category) {
				foreach ($category as $term) {
					$categories .= $term->name . ",";
				}
			}

			$categories = rtrim( $categories, "," );

			$cart_checkout_products[get_permalink($p->id)]	=	array(
					"p_ID" 			=>	esc_html( $p->id ),
					"p_sku"			=>	esc_html( $p->get_sku() ? $p->get_sku() : $p->id ),
					"p_name"		=>	esc_html( $p->get_title() ),
					"p_price"		=>	esc_html( $p->get_price() ),
					"p_category"	=>	esc_html( $categories ),
					"p_quantity"	=>	$value["quantity"]
			);
		}

		$this->add_inline_js_wpa_woo( "cart_checkout_products=" . json_encode( $cart_checkout_products ) . ";" );

		$code = '

                for(var item in cart_checkout_products) {

					ga("ec:addProduct", {
						"id": cart_checkout_products[item].p_ID,
						"name": cart_checkout_products[item].p_name,
						"category": cart_checkout_products[item].p_category,
						"price": cart_checkout_products[item].p_price,
						"quantity": cart_checkout_products[item].p_quantity
					});
				}';

        $code  = $code . 'ga("ec:setAction","checkout", { "step": 2 });';
        $code .= 'ga( "send", "event", "Tracking by Analytify","onLoad","Product Checkout Billing Form" );';

        $this->add_inline_js_wpa_woo( $code );

	}

	/*
	 * Tracking Product Checkouts - Step 3
	 * Shipping
	 */
	function product_checkout_step3() {

		global $woocommerce;
		
		$cart_products = array();
		$categories = '';
		$code = '';

		foreach ( $woocommerce->cart->cart_contents as $key => $value ) {

			$p = get_product( $value["product_id"] );

			$category = get_the_terms( $value["product_id"], "product_cat" );

			if ($category) {
				foreach ($category as $term) {
					$categories .= $term->name . ",";
				}
			}

			$categories = rtrim( $categories, "," );

			$cart_checkout_products[get_permalink($p->id)]	=	array(
					"p_ID" 			=>	esc_html( $p->id ),
					"p_sku"			=>	esc_html( $p->get_sku() ? $p->get_sku() : $p->id ),
					"p_name"		=>	esc_html( $p->get_title() ),
					"p_price"		=>	esc_html( $p->get_price() ),
					"p_category"	=>	esc_html( $categories ),
					"p_quantity"	=>	$value["quantity"]
			);
		}

		$this->add_inline_js_wpa_woo( "cart_checkout_products=" . json_encode( $cart_checkout_products ) . ";" );

		$code = '

                for(var item in cart_checkout_products) {

					ga("ec:addProduct", {
						"id": cart_checkout_products[item].p_ID,
						"name": cart_checkout_products[item].p_name,
						"category": cart_checkout_products[item].p_category,
						"price": cart_checkout_products[item].p_price,
						"quantity": cart_checkout_products[item].p_quantity
					});
				}';

        $code  = $code . 'ga("ec:setAction","checkout", { "step": 3 });';
        $code .= 'ga( "send", "event", "Tracking by Analytify","onLoad","Product Checkout Shipping Form" );';

        $this->add_inline_js_wpa_woo( $code );

	}

	/*
	 * Tracking Product Checkouts - Step 4
	 * Checkout
	 */
	function product_checkout_step4() {

		global $woocommerce;
		
		$cart_products = array();
		$categories = '';
		$code = '';

		foreach ( $woocommerce->cart->cart_contents as $key => $value ) {

			$p = get_product( $value["product_id"] );

			$category = get_the_terms( $value["product_id"], "product_cat" );

			if ($category) {
				foreach ($category as $term) {
					$categories .= $term->name . ",";
				}
			}

			$categories = rtrim( $categories, "," );

			$cart_checkout_products[get_permalink($p->id)]	=	array(
					"p_ID" 			=>	esc_html( $p->id ),
					"p_sku"			=>	esc_html( $p->get_sku() ? $p->get_sku() : $p->id ),
					"p_name"		=>	esc_html( $p->get_title() ),
					"p_price"		=>	esc_html( $p->get_price() ),
					"p_category"	=>	esc_html( $categories ),
					"p_quantity"	=>	$value["quantity"]
			);
		}

		$this->add_inline_js_wpa_woo( "cart_checkout_products=" . json_encode( $cart_checkout_products ) . ";" );

		$code = '

                for(var item in cart_checkout_products) {

					ga("ec:addProduct", {
						"id": cart_checkout_products[item].p_ID,
						"name": cart_checkout_products[item].p_name,
						"category": cart_checkout_products[item].p_category,
						"price": cart_checkout_products[item].p_price,
						"quantity": cart_checkout_products[item].p_quantity
					});
				}';

        $code  = $code . 'ga("ec:setAction","checkout", { "step": 4 });';
        $code .= 'ga( "send", "event", "Tracking by Analytify","onLoad","Product Checkout Form" );';

        $this->add_inline_js_wpa_woo( $code );

	}


	/**
	 * Display notices for woocommerce users
	 * @since 1.0.2
	 */
	function wp_analytify_woo_admin_notice() {

		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		if( get_option( 'analytify_woo_license_key' ) == 'invalid' ){


		}else{


			
		}

		// /* Show notices */
  //       if (! isset( $acces_token ) || empty( $acces_token ) || ! get_option( 'pa_google_token' ) ) {

		// 	echo sprintf( esc_html__( '%1$s %2$s %3$sNotice:%4$s%5$sConnect%6$s%4$s Analytify with your Google account. %7$s %8$s', 'wp-analytify'), '<div class="error notice is-dismissible">', '<p>', '<b>', '</b>', '<b><a style="text-decoration:none" href=' . menu_page_url ( 'analytify-settings', false ) . '>', '</a>','</p>', '</div>');
		// }
		// else{

		// 	if ((! isset( $profile_id ) || empty( $profile_id )) && ! isset($_POST[ 'save_profile' ]) ) {

		// 		echo '<div class="error notice is-dismissible"><p>' . sprintf( esc_html__( 'Congratulations! Analytify is now authenticated. Please select your website profile %1$s here %2$s', 'wp-analytify' ), '<a style="text-decoration:none" href="' . menu_page_url ( 'analytify-settings', false ) . '&tab=profile">','</a>') . '</p></div>';
		// 	}
		// }

	}

}

/**
 * Returns the main instance of WP_Analytify_WooCommerce to prevent the need to use globals.
 *
 * @since  1.0.0
 * @return WP_Analytify_WooCommerce
 */
function WPAnalytifyWooCommerce() {
	return WP_Analytify_WooCommerce::instance();
}

// Global for backwards compatibility.
$GLOBALS['WPAnalytifyWooCommerce'] = WPAnalytifyWooCommerce();
?>